@@ -2,7 +2,7 @@
 
 __author__ = """Qiusheng Wu"""
 __email__ = "giswqs@gmail.com"
-__version__ = "0.15.2"
+__version__ = "0.16.8"
 
 import os
 
@@ -30,9 +30,9 @@ if use_folium():
 else:
     from .geemap import *
 
-    if in_colab_shell():
-        from google.colab import output
+    # if in_colab_shell():
+    #     from google.colab import output
 
-        output.enable_custom_widget_manager()
+    #     output.enable_custom_widget_manager()
 
 from .report import Report
